@@ -2,7 +2,11 @@ from .client_config import ClientNotFoundError
 from .components.buildx.cli_wrapper import Builder
 from .components.config.cli_wrapper import Config
 from .components.container.cli_wrapper import Container, ContainerStats
-from .components.context.cli_wrapper import Context
+from .components.context.cli_wrapper import (
+    Context,
+    DockerContextConfig,
+    KubernetesContextConfig,
+)
 from .components.image.cli_wrapper import Image
 from .components.network.cli_wrapper import Network
 from .components.node.cli_wrapper import Node
@@ -18,3 +22,25 @@ from .exceptions import DockerException
 
 # alias
 docker = DockerClient()
+
+__all__ = [
+    "Builder",
+    "ClientNotFoundError",
+    "Config",
+    "Container",
+    "ContainerStats",
+    "Context",
+    "DockerContextConfig",
+    "DockerException",
+    "Image",
+    "KubernetesContextConfig",
+    "Network",
+    "Node",
+    "Plugin",
+    "Secret",
+    "Service",
+    "Stack",
+    "SystemInfo",
+    "Task",
+    "Volume",
+]
