@@ -27,9 +27,8 @@ image_app = typer.Typer()
 
 
 @image_app.command()
-def copy_from(docker_image: str, source: str, destination: str):
-    image = docker.image._pull_if_necessary(docker_image)
-    docker.image.copy_from(image, source, destination)
+def copy_from(docker_image: str, source: str, destination: str, pull: str = "missing"):
+    docker.image.copy_from(docker_image, source, destination, pull)
 
 
 @image_app.command()
@@ -39,9 +38,9 @@ def copy_to(
     destination: str,
     new_tag: Optional[str] = None,
     push: bool = False,
+    pull: str = "missing",
 ):
-    image = docker.image._pull_if_necessary(docker_image)
-    docker.image.copy_to(image, source, destination, new_tag)
+    docker.image.copy_to(docker_image, source, destination, new_tag, pull)
     if push:
         docker.image.push(new_tag)
 
