@@ -75,12 +75,12 @@ class DockerCamelModel(pydantic.BaseModel):
 @overload
 def run(
     args: List[Any],
-    capture_stdout: bool = True,
-    capture_stderr: bool = True,
-    input: bytes = None,
-    return_stderr: Literal[True] = False,
-    env: Dict[str, str] = {},
-    tty: bool = False,
+    capture_stdout: bool = ...,
+    capture_stderr: bool = ...,
+    input: bytes = ...,
+    return_stderr: Literal[True] = ...,
+    env: Dict[str, str] = ...,
+    tty: bool = ...,
 ) -> Tuple[str, str]:
     ...
 
@@ -88,12 +88,12 @@ def run(
 @overload
 def run(
     args: List[Any],
-    capture_stdout: bool = True,
-    capture_stderr: bool = True,
-    input: bytes = None,
-    return_stderr: Literal[False] = False,
-    env: Dict[str, str] = {},
-    tty: bool = False,
+    capture_stdout: bool = ...,
+    capture_stderr: bool = ...,
+    input: bytes = ...,
+    return_stderr: Literal[False] = ...,
+    env: Dict[str, str] = ...,
+    tty: bool = ...,
 ) -> str:
     ...
 
@@ -102,7 +102,7 @@ def run(
     args: List[Any],
     capture_stdout: bool = True,
     capture_stderr: bool = True,
-    input: bytes = None,
+    input: Optional[bytes] = None,
     return_stderr: bool = False,
     env: Dict[str, str] = {},
     tty: bool = False,
@@ -313,3 +313,10 @@ def format_time_for_docker(time_object: Union[datetime, timedelta]) -> str:
         return time_object.strftime("%Y-%m-%dT%H:%M:%S")
     elif isinstance(time_object, timedelta):
         return f"{time_object.total_seconds()}s"
+
+
+def parse_ls_status_count(status_output, status) -> int:
+    try:
+        return int(status_output.split(status + "(")[1].split(")")[0])
+    except IndexError:
+        return 0
